import PropTypes from "prop-types";
import { motion, AnimatePresence } from "motion/react";
function FormInput({
  value,
  onChange,
  valid = true,
  maxLength = 17,
  readOnly = false,
  className = "",
  type = "text",
}) {
  return (
    <div>
      <input
        readOnly={readOnly}
        value={value}
        className={`w-72 h-10 px-2 rounded-full dark:bg-white dark:text-grey border-2 text-grey focus:outline-grey ${className}`}
        onChange={onChange}
        type={type}
        maxLength={maxLength}
      />
      <AnimatePresence>
        {!valid && (
          <motion.div
            className="text-sm text-error ml-3 pt-1"
            initial={{ y: 15, opacity: 0 }}
            animate={{ y: 0, opacity: 1 }}
            exit={{ y: 15, opacity: 0 }}
            key="cabinetIdError"
          >
            Invalid Value
          </motion.div>
        )}
      </AnimatePresence>
    </div>
  );
}

FormInput.propTypes = {
  value: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  readOnly: PropTypes.bool,
  className: PropTypes.string,
  type: PropTypes.string,
  maxLength: PropTypes.number,
  valid: PropTypes.bool,
};

export default FormInput;
