import PropTypes from "prop-types";
import { motion, AnimatePresence } from "motion/react";

function FormSelect({ value, onChange, options, className, valid = true }) {
  return (
    <div>
    <select
      value={value}
      className={
        "w-72 h-10 px-2 rounded-full dark:bg-white dark:text-grey border-2 text-grey focus:outline-grey " +
        className
      }
      onChange={onChange}
    >
      <option disabled value="">
        Select
      </option>
      {options.map(({ value, label }) => (
        <option key={value} value={value}>
          {label}
        </option>
      ))}
    </select>
    <AnimatePresence>
        {!valid && (
          <motion.div
            className="text-sm text-error ml-3 pt-1"
            initial={{ y: 15, opacity: 0 }}
            animate={{ y: 0, opacity: 1 }}
            exit={{ y: 15, opacity: 0 }}
            key="cabinetIdError"
          >
            Invalid Value
          </motion.div>
        )}
      </AnimatePresence>
  </div>
  );
}

FormSelect.propTypes = {
  value: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  className: PropTypes.string,
  valid: PropTypes.bool,
  options: PropTypes.arrayOf(
    PropTypes.shape({
      value: PropTypes.string.isRequired,
      label: PropTypes.string.isRequired,
    })
  ).isRequired,
};

export default FormSelect;
